@@ -2,7 +2,7 @@
 ".First.lib" <- 
 function(libname, pkgname)
 {
-   require(methods, quietly = TRUE, warn.conflicts = FALSE)
+   require("methods", quietly = TRUE, warn.conflicts = FALSE)
 }
 
 .onLoad <- .First.lib
